@@ -1,6 +1,6 @@
 import pytest
 from django.core.exceptions import ValidationError
-from pytest_lazyfixture import lazy_fixture
+from pytest_lazy_fixtures import lf as lazy_fixture
 
 from timezone_field import TimeZoneField
 
